#
# spec file for package perl-Mojolicious-Plugin-AssetPack
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Mojolicious-Plugin-AssetPack
Name:           perl-Mojolicious-Plugin-AssetPack
Version:        2.14
Release:        1.3
Summary:        Compress and convert CSS, Less, Sass, JavaScript and CoffeeScript files
License:        Artistic-2.0
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/S/SR/SRI/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(File::Which) >= 1.21
BuildRequires:  perl(IPC::Run3) >= 0.048
BuildRequires:  perl(Mojolicious) >= 9.0
BuildRequires:  perl(Test::More) >= 0.88
Requires:       perl(File::Which) >= 1.21
Requires:       perl(IPC::Run3) >= 0.048
Requires:       perl(Mojolicious) >= 9.0
%{perl_requires}

%description
Mojolicious::Plugin::AssetPack is a Mojolicious plugin for processing
static assets. The idea is that JavaScript and CSS files should be served
as one minified file to save bandwidth and roundtrip time to the server.

There are many external tools for doing this, but integrating them with
Mojolicious can be a struggle: You want to serve the source files directly
while developing, but a minified version in production. This assetpack
plugin will handle all of that automatically for you.

Your application creates and refers to an asset by its topic (virtual asset
name). The process of building actual assets from their components is
delegated to "pipe objects".

%prep
%autosetup  -n %{cpan_name}-%{version}
find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes examples README.md
%license LICENSE

%changelog
* Wed Feb  8 2023 Ondřej Súkup <mimi.vx@gmail.com>
- updated to 2.14
  * added support for retry during download assets
* Sun Mar 14 2021 Tina Müller <timueller+perl@suse.de>
- updated to 2.13
  see /usr/share/doc/packages/perl-Mojolicious-Plugin-AssetPack/Changes
* Fri Feb 19 2021 Tina Müller <timueller+perl@suse.de>
- updated to 2.11
  see /usr/share/doc/packages/perl-Mojolicious-Plugin-AssetPack/Changes
  2.11 2021-02-19T10:23:04+0900
  - Use 'partial(1)->to' instead of 'detour' which was deprecated in Mojolicious 9.0
    Contributor: Marius Kittler
* Sat Dec 12 2020 Tina Müller <timueller+perl@suse.de>
- updated to 2.10
  see /usr/share/doc/packages/perl-Mojolicious-Plugin-AssetPack/Changes
  2.10 2020-12-11T11:16:01+0900
  - Fixes warnings issued by latest Mojolicious
    Contributor: Zoffix Znet
* Mon Sep  7 2020 Tina Müller <timueller+perl@suse.de>
- updated to 2.09
  see /usr/share/doc/packages/perl-Mojolicious-Plugin-AssetPack/Changes
  2.09 2020-09-07T08:56:50+0900
  - Prevent JavaScript from runnning in 404 assets #140
  - Slimmed down the bundled documentation
* Wed May  8 2019 Stephan Kulow <coolo@suse.com>
- updated to 2.08
  see /usr/share/doc/packages/perl-Mojolicious-Plugin-AssetPack/Changes
  2.08 2019-05-07T21:16:40+0700
  - Fix link to Mojolicious::Plugin::Webpack
* Sun May  5 2019 Stephan Kulow <coolo@suse.com>
- updated to 2.07
  see /usr/share/doc/packages/perl-Mojolicious-Plugin-AssetPack/Changes
  2.07 2019-05-04T23:54:32+0700
  - Add RollupJs->add_global();
  - Add note about Mojolicious::Plugin::AssetPack::Webpack
* Wed Sep 19 2018 Stephan Kulow <coolo@suse.com>
- updated to 2.06
  see /usr/share/doc/packages/perl-Mojolicious-Plugin-AssetPack/Changes
* Thu Aug  2 2018 coolo@suse.com
- updated to 2.05
  see /usr/share/doc/packages/perl-Mojolicious-Plugin-AssetPack/Changes
  2.05 2018-08-01T14:19:35+0800
  - Fix s///r is not supported in older Perls #136
  - Fix Favicon rendering of manifest and browserconfig
  - Add Asset::renderer() for dynamic assets
  - Add fallback for serving assets with wrong checksum
  - Renamed Asset::renderer() to tag_for()
* Fri Jul 20 2018 coolo@suse.com
- updated to 2.04
  see /usr/share/doc/packages/perl-Mojolicious-Plugin-AssetPack/Changes
  2.04 2018-07-19T17:39:06+0800
  - Add support for generating manifest with Favicon pipe
  - Marked AssetPack::tag_for() as deprecated
  - Removed support for Mojolicious::Plugin::AssetPack::Backcompat
* Fri Apr 27 2018 coolo@suse.com
- updated to 2.03
  see /usr/share/doc/packages/perl-Mojolicious-Plugin-AssetPack/Changes
  2.03 2018-04-26T10:22:06+0200
  - Ensure asset is processed when calling processed
  - Update favicon generator URL to use https
  - Set higher inactivity timeout for favicon generator
* Wed Feb  7 2018 coolo@suse.com
- updated to 2.02
  see /usr/share/doc/packages/perl-Mojolicious-Plugin-AssetPack/Changes
* Wed Nov  8 2017 coolo@suse.com
- updated to 2.01
  see /usr/share/doc/packages/perl-Mojolicious-Plugin-AssetPack/Changes
  2.01 2017-11-06T13:02:45+0100
  - Up version number to try to fix pause indexing issues
  1.48 2017-10-29T10:20:51+0800
  - Fix RollupJs package name #130
  - load_module() confess on error
  - Removed EXPERIMENTAL Reloader pipe
  - Removed EXPERIMENTAL clone() method in AssetPack::Asset
* Tue Oct 17 2017 coolo@suse.com
- updated to 1.47
  see /usr/share/doc/packages/perl-Mojolicious-Plugin-AssetPack/Changes
  1.47 2017-10-14T18:58:55+0200
  - Dropping "original" from assetpack.db
* Thu Sep 28 2017 coolo@suse.com
- updated to 1.46
  see /usr/share/doc/packages/perl-Mojolicious-Plugin-AssetPack/Changes
  1.46 2017-09-27T21:35:33+0200
  - Add "asset_class" attribute to AssetPack::Store
  - Add rollupjs pipe - https://rollupjs.org/
* Tue Jun 20 2017 coolo@suse.com
- updated to 1.45
  see /usr/share/doc/packages/perl-Mojolicious-Plugin-AssetPack/Changes
  1.45 2017-06-19T23:49:30+0200
  - Add Developing guide
  - Removed deprecated method end_range() from AssetPack::Asset
  - Removed deprecated method get_chunk() from AssetPack::Asset
  - Removed deprecated method is_range() from AssetPack::Asset
  - Removed deprecated method mtime() from AssetPack::Asset
  - Removed deprecated method start_range() from AssetPack::Asset
  - Removed deprecated method tag_helper() from AssetPack::Asset
  - Removed MOJO_ASSETPACK_CLEANUP (only used in test suite)
  - Can prevent AssetPack::Store from writing assetpack.db while developing
    with MOJO_ASSETPACK_LAZY=1 (EXPERIMENTAL)
* Thu May 25 2017 coolo@suse.com
- updated to 1.44
  see /usr/share/doc/packages/perl-Mojolicious-Plugin-AssetPack/Changes
  1.44 2017-05-21T23:02:46+0200
  - Improved documentation #125
    Contributor: William Lindley
* Tue May 16 2017 coolo@suse.com
- updated to 1.43
  see /usr/share/doc/packages/perl-Mojolicious-Plugin-AssetPack/Changes
  1.43 2017-05-12T14:38:02+0200
  - Fix not escaping Vuejs template code
  - Less verbose logging when processing assets
* Sun Apr 30 2017 coolo@suse.com
- updated to 1.42
  see /usr/share/doc/packages/perl-Mojolicious-Plugin-AssetPack/Changes
  1.42 2017-04-29T14:23:37+0200
  - Fix missing use lib '.' in register.t #124
  - Add fetching of source maps to "Fetch" pipe #117
* Fri Mar 17 2017 coolo@suse.com
- updated to 1.41
  see /usr/share/doc/packages/perl-Mojolicious-Plugin-AssetPack/Changes
  1.41 2017-03-15T22:09:14+0100
  - Fix bug in @import regex used by Pipe::Sass
* Wed Feb  8 2017 coolo@suse.com
- updated to 1.40
  see /usr/share/doc/packages/perl-Mojolicious-Plugin-AssetPack/Changes
  1.40 2017-02-05T15:10:58-0800
  - Fix skipping @import in comments #121
  - Improved documentation for assetpack.def and paths #110
  - Can disable Pipe::Reloader from the browser
* Thu Jan 26 2017 coolo@suse.com
- updated to 1.39
  see /usr/share/doc/packages/perl-Mojolicious-Plugin-AssetPack/Changes
  1.39 2017-01-25T22:39:45+0100
  - Skipping t/sass-source-map.t for now
    http://cpantesters.org/cpan/report/c59d94d4-e16e-11e6-ab5a-96809f28caea
* Tue Jan 24 2017 coolo@suse.com
- updated to 1.38
  see /usr/share/doc/packages/perl-Mojolicious-Plugin-AssetPack/Changes
  1.38 2017-01-23T14:12:31+0100
  - Fix missing path() function in Pipe::Sass
* Sat Jan 14 2017 coolo@suse.com
- updated to 1.37
  see /usr/share/doc/packages/perl-Mojolicious-Plugin-AssetPack/Changes
  1.37 2017-01-12T20:52:18+0100
  - Add support for sass source maps
  - No need to delete known media types in AssetPack::Store
* Wed Jan 11 2017 coolo@suse.com
- updated to 1.36
  see /usr/share/doc/packages/perl-Mojolicious-Plugin-AssetPack/Changes
  1.36 2017-01-11T11:18:45+0100
  - Fix bug in Fetch pipe, fixing t/font-awesome.t
  - Change Mojolicious::Plugin::AssetPack::Asset::path() to return a Mojo::File object
  1.35 2017-01-11T10:30:09+0100
  - Forgot to remove Carp::Always from t/recreate.t after debugging
  1.34 2017-01-10T23:22:16+0100
  - Compatible with Mojolicious 7.15
  1.33 2017-01-08T14:20:03+0100
  - Fix t/reloader.t when CSS::Minifier::XS is missing #113
  1.32 2017-01-08T11:50:36+0100
  - Fix Mojo::Home::rel_dir is DEPRECATED in favor of Mojo::Hom::rel_file #112
  - Disable "Reloader" pipe, unless in development
* Fri Jan  6 2017 coolo@suse.com
- updated to 1.31
  see /usr/share/doc/packages/perl-Mojolicious-Plugin-AssetPack/Changes
  1.31 2017-01-04T14:19:34+0100
  - Fix generating favicons once with MOJO_ASSETPACK_LAZY
  - Made Reloader call process() later
* Sat Dec 24 2016 coolo@suse.com
- updated to 1.30
  see /usr/share/doc/packages/perl-Mojolicious-Plugin-AssetPack/Changes
  1.30 2016-12-23T03:14:34+0100
  - Fix CoffeeScript, by changing to coffee-script npm package
  - Add EXPERIMENTAL support for MOJO_ASSETPACK_LAZY=1
  - Marked AssetPack::Asset::mtime() as deprecated
* Fri Dec 16 2016 coolo@suse.com
- updated to 1.29
  see /usr/share/doc/packages/perl-Mojolicious-Plugin-AssetPack/Changes
  1.29 2016-12-15T23:04:40+0100
  - Fix custom helper name #111
* Fri Nov 25 2016 coolo@suse.com
- updated to 1.28
  see /usr/share/doc/packages/perl-Mojolicious-Plugin-AssetPack/Changes
  1.28 2016-11-24T10:51:55+0100
  - Fix resetting end_range and start_range after a "Range: bytes=..." request #109
* Sat Nov 19 2016 coolo@suse.com
- updated to 1.27
  see /usr/share/doc/packages/perl-Mojolicious-Plugin-AssetPack/Changes
  1.27 2016-11-18T15:13:55+0100
  - Add custom 404 page when an asset could not be found
* Mon Nov 14 2016 coolo@suse.com
- updated to 1.26
  see /usr/share/doc/packages/perl-Mojolicious-Plugin-AssetPack/Changes
  1.26 2016-11-13T17:50:42+0100
  - Change Pipe::Fetch to avoid fetching URL that start with "#" #108
* Mon Oct 31 2016 coolo@suse.com
- updated to 1.25
  see /usr/share/doc/packages/perl-Mojolicious-Plugin-AssetPack/Changes
  1.25 2016-10-30T21:24:48+0100
  - Add end_range(), start_range() and is_range() to Asset #104
* Mon Sep 12 2016 coolo@suse.com
- updated to 1.24
  see /usr/share/doc/packages/perl-Mojolicious-Plugin-AssetPack/Changes
  1.24 2016-09-11T17:22:08+0200
  - Forgot to delete t/sass-current-app.t after 1.23
  1.23 2016-09-11T17:01:57+0200
  - Add EXPERIMENTAL support for mixing in dynamic SASS files
* Sat Sep  3 2016 coolo@suse.com
- updated to 1.22
  see /usr/share/doc/packages/perl-Mojolicious-Plugin-AssetPack/Changes
  1.22 2016-09-02T14:27:42+0200
  - Fix showing error message when asset could not be found
* Fri Sep  2 2016 coolo@suse.com
- updated to 1.21
  see /usr/share/doc/packages/perl-Mojolicious-Plugin-AssetPack/Changes
  1.21 2016-08-29T15:48:01+0200
  - Add support for merging assetpack.db files
* Sat Aug 20 2016 coolo@suse.com
- updated to 1.20
  see /usr/share/doc/packages/perl-Mojolicious-Plugin-AssetPack/Changes
  1.20 2016-08-19T15:11:58+0200
  - Add EXPERIMENTAL Mojolicious::Plugin::AssetPack::Pipe::TypeScript
  - Will default to "==" test when checking mode in assetpack.def
  - Moved Backcompat to the Mojolicious-Plugin-AssetPack-Backcompat dist
* Thu Aug 11 2016 coolo@suse.com
- updated to 1.19
  see /usr/share/doc/packages/perl-Mojolicious-Plugin-AssetPack/Changes
  1.19 2016-08-10T19:14:16+0200
  - Add EXPERIMENTAL support for compiling .vue (Vue.js) files
* Tue Jul 26 2016 coolo@suse.com
- updated to 1.18
  see /usr/share/doc/packages/perl-Mojolicious-Plugin-AssetPack/Changes
  1.18 2016-07-25T17:52:06+0200
  - Fix Can't locate object method "authority" via package "Mojo::URL" #102
* Tue Jul 19 2016 coolo@suse.com
- updated to 1.17
  see /usr/share/doc/packages/perl-Mojolicious-Plugin-AssetPack/Changes
  1.17 2016-07-18T18:43:23+0200
  - Removed Mojolicious::Plugin::AssetPack::Asset::tag_helper()
  - Add Mojolicious::Plugin::AssetPack::tag_for()
  - Add Mojolicious::Plugin::AssetPack::Asset::url_for()
  - Add EXPERIMENTAL Mojolicious::Plugin::AssetPack::Pipe::Favicon
  - Add support for gif, ico, mp3, mp4, ogg, ogv, svg and webm.
* Mon Jul  4 2016 coolo@suse.com
- updated to 1.16
  see /usr/share/doc/packages/perl-Mojolicious-Plugin-AssetPack/Changes
  1.16 2016-06-29T19:05:43+0200
  - Improved documentation for store() #101
* Fri Jun 24 2016 coolo@suse.com
- updated to 1.15
  see /usr/share/doc/packages/perl-Mojolicious-Plugin-AssetPack/Changes
  1.15 2016-06-23T10:50:26+0200
  - Fix Fetch pipe will skip downloading "data:..." urls #100
* Thu Jun 23 2016 coolo@suse.com
- updated to 1.14
  see /usr/share/doc/packages/perl-Mojolicious-Plugin-AssetPack/Changes
  1.14 2016-06-21T13:33:41+0200
  - Fix Fetch::URL_RE for url(...) without quotes #91 #99
  - Fix trimming whitespace for topics in .def file, closes #93
  - Fix replacing all fetched files #94
  - Will show download error message #96
* Tue May 31 2016 coolo@suse.com
- updated to 1.13
  see /usr/share/doc/packages/perl-Mojolicious-Plugin-AssetPack/Changes
  1.13 2016-05-21T08:11:27+0200
  - Fix sass-current-app.t after 1.12
  1.12 2016-05-20T20:59:10+0200
  - Fix compressing Sass assets with SASS_STYLE_COMPRESSED
    Contributor: Zoffix Znet
  1.11 2016-05-17T07:55:56+0200
  - Fix failing reloader-process.t
  1.10 2016-05-15T11:50:24+0200
  - Fix watching the actual input asset files in Pipe::Reloader #86
    Contributor: Mark Grimes
  1.09 2016-05-10T21:36:09+0200
  - Fix to deal with multiple imports of the same Sass file #83
    Contributor: Mark Grimes
  1.08 2016-05-09T22:23:42+0200
  - Add support for minifying jpeg image files
  - Add support for minifying png image files #81
    Contributor: Heiko Jansen
  - Add Mojolicious::Plugin::AssetPack::Asset::tag_helper() to support
    future "image" assets.
  1.07 2016-05-03T13:55:45+0200
  - Fix rendering assets URL in mounted apps
  1.06 2016-04-17T14:22:08+0200
  - Fix Fetch with Combine #75
  1.05 2016-04-17T11:19:29+0200
  - Need to "use CSS::Sass 3.3.0" to avoid test failures on missing features
  - Add support for automatic download of fonts #75
  - Add support for conditions in assetpack.def #78
  - Fix SCSS files with UTF-8 encoding #70
  - Fix adding route earlier than on the first request #77
  - Fix setting url() on asset from db file
  1.04 2016-04-08T22:40:29+0200
  - Fix Pipe::Reloader and files from def file
  - Change default Pipe::Reloader strategy to "document" to make reloading
    JavaScript more robust.
  1.03 2016-04-08T20:15:31+0200
  - Add Pipe::Reloader for instant refresh in browser on asset change #72
  - Marked old modules as deprecated
  1.02 2016-04-08T14:30:19+0200
  - Add support for "sass_functions" #68
    Contributor: Mark Grimes
  - Fix 2 naked subroutines
  - Fix t/sass.t: #919191 != #909090
  - Skip more old tests by default
  1.01 2016-04-06T16:10:06+0200
  - Cannot load CSS::Minifier::XS in old code - The module is optional
  - Cannot load JavaScript::Minifier::XS in old code - The module is optional
  1.00 2016-04-02T21:26:35+0200
  - Rewrote the module. Breaking changes might occur.
  - Changed from "pre-processors" to "pipes"
* Sat Dec  5 2015 coolo@suse.com
- updated to 0.69
  see /usr/share/doc/packages/perl-Mojolicious-Plugin-AssetPack/Changes
  0.69 2015-12-02T16:37:36+0100
  - Fix "uninitialized value" warning in Scss.pm line 203 #65
  - Fix fetch() from $app
* Mon Sep 28 2015 coolo@suse.com
- updated to 0.68
  see /usr/share/doc/packages/perl-Mojolicious-Plugin-AssetPack/Changes
  0.68 2015-09-28T08:28:29+0200
  - Will skip tests unless possible to write to out_dir
  0.67 2015-09-27T15:24:23+0200
  - Fix asset can be read-only
  0.66 2015-09-27T14:56:56+0200
  - Skip some tests on windows
  - Remove EXPERIMENTAL remark for wildcards in filenames #52
  - Remove EXPERIMENTAL remark from headers()
  - Remove EXPERIMENTAL remark from source_paths()
* Sat Sep 26 2015 coolo@suse.com
- updated to 0.65
  see /usr/share/doc/packages/perl-Mojolicious-Plugin-AssetPack/Changes
  0.65 2015-09-25T16:55:49+0200
  - Add EXPERIMENTAL fixed mapping between moniker to packed files #64
  - Add EXPERIMENTAL test_app() to ensure all assets are created
  - Change headers() into a method
  - Change out_dir() into a read-only method, as documented
  - Remove EXPERIMENTAL support for reloader.js
  - Remove deprecated preprocessor() method
  - Remove support for in-memory assets #64
  - Fix memory leak
* Sun Sep 20 2015 coolo@suse.com
- updated to 0.64
  see /usr/share/doc/packages/perl-Mojolicious-Plugin-AssetPack/Changes
  0.64 2015-09-20T11:44:26+0200
  - Add "SHIPPING" section to Cookbook
  - Fix adding custom response headers when assets are already built #55
  - Fix always add newline to JavaScript assets to prevent issues with comments
  - Improved logging for in-memory assets
  - Improved error reporting when unable to build assets
* Sat Aug 29 2015 coolo@suse.com
- updated to 0.63
  see /usr/share/doc/packages/perl-Mojolicious-Plugin-AssetPack/Changes
  0.63 2015-08-29T00:51:29+0200
  - Fix responding 404 when in-memory asset could not be found
  - Add support for custom response headers #55
  0.62 2015-08-27T11:40:41-0400
  - Fix @import tracking #62
* Mon Aug 24 2015 coolo@suse.com
- updated to 0.61
  see /usr/share/doc/packages/perl-Mojolicious-Plugin-AssetPack/Changes
  0.61 2015-08-23T13:34:34+0200
  - Add include_paths() to Scss preprocessor
  - Fix using SASS_PATH environment variable when calculating checksum #60
  - Deprecating asset->preprocessor() in favor of asset->preprocessors->add()
* Sun Aug 23 2015 coolo@suse.com
- updated to 0.60
  see /usr/share/doc/packages/perl-Mojolicious-Plugin-AssetPack/Changes
  0.60 2015-08-20T17:21:54+0200
  - Fix detecting changed sass/scss files in sub directories, with leading underscore
  0.59 2015-08-20T14:42:25+0200
  - Cannot look for packed files in "source_paths"
  - MOJO_ASSETPACK_DEBUG need to be set to "2" for more verbose debug
  0.58 2015-08-09T14:28:04+0200
  - Change "source_paths" to return original reference and not a copy
  - Need to look for packed files in all directories (source_paths+public)
  0.57 2015-08-09T11:34:21+0200
  - Add support for "source_paths" (EXPERIMENTAL) #58
  - Add support for fetching assets using a proxy
* Sat Aug  8 2015 coolo@suse.com
- updated to 0.56
  see /usr/share/doc/packages/perl-Mojolicious-Plugin-AssetPack/Changes
  0.56 2015-08-05T10:44:15+0200
  - Add purge() method (EXPERIMENTAL)
  - Add support for wildcards in filenames (EXPERIMENTAL) #52
* Sun Jun  7 2015 coolo@suse.com
- updated to 0.55
  see /usr/share/doc/packages/perl-Mojolicious-Plugin-AssetPack/Changes
  0.55 2015-05-25T12:58:04+0200
  - Will not add memory asset route if not needed #56
  - Make error visible regardless of page scroll position #57
    Contributor: Zoffix Znet
* Fri Apr 24 2015 coolo@suse.com
- updated to 0.54
  see /usr/share/doc/packages/perl-Mojolicious-Plugin-AssetPack/Changes
* Mon Apr 20 2015 coolo@suse.com
- updated to 0.5201
  see /usr/share/doc/packages/perl-Mojolicious-Plugin-AssetPack/Changes
* Sun Apr 19 2015 coolo@suse.com
- updated to 0.52
  see /usr/share/doc/packages/perl-Mojolicious-Plugin-AssetPack/Changes
* Thu Apr 16 2015 coolo@suse.com
- updated to 0.51
  see /usr/share/doc/packages/perl-Mojolicious-Plugin-AssetPack/Changes
* Mon Apr 13 2015 coolo@suse.com
- updated to 0.50
  see /usr/share/doc/packages/perl-Mojolicious-Plugin-AssetPack/Changes
  0.50 2015-04-13T11:37:08+0200
  * Need to start with a fresh asset to avoid adding duplicate
    processed data to the same asset.
  0.49     Sun Apr  5 09:54:27 2015
  * Will not pack asset.ext.swp files
  0.48     Sun Apr  5 09:19:01 2015
  * Fix serving in memory assets with Content-Type
  * Fix serving in memory assets with Last-Modified
  0.47     Sat Apr  4 13:53:32 2015
  * Fix Mojo::Base::tap() does not support arguments before 5.57
  0.4602   Thu Apr  2 18:44:01 2015
  * Improved cpantesters
  0.46     Wed Apr  1 15:09:35 2015
  * Remove "fallback" attribute #44 (experimental)
  * Remove "process" method
  * Will prevent AssetPack from registering twice
  * Will not write assets to "mojo-assetpack-public" in TMPDIR #46 (experimental)
  * Allow in-memory assets with out_dir(""), MOJO_ASSETPACK_DEBUG=1 or
    read-only static dirs. #46 (experimental)
  0.45     Tue Mar 31 22:02:06 2015
  * Can also fetch remote assets from local $app #30
  * Will calculate MD5 sum recursively for sass/scss #44
  * Add Cookbook
* Mon Mar 23 2015 coolo@suse.com
- updated to 0.44
  * Add ".min.ext" to minified asset filename
  * Change filename for assets with errors from "-with-error.ext" to ".err.ext"
  * Will look for existing assets even with MOJO_ASSETPACK_DEBUG=1
  * Remove errmsg() from Mojolicious::Plugin::AssetPack::Preprocessor
  * Remove detect() from Mojolicious::Plugin::AssetPack::Preprocessors
  0.43     Fri Mar 20 11:27:22 2015
  * Same CSS::Sass detection for Sass as for Scss preprocessor
* Fri Mar 20 2015 coolo@suse.com
- updated to 0.42
  * Fix "Unescaped left brace in regex is deprecated" warnings
  0.41     Mon Mar 16 13:47:17 2015
  * Will die on CSS::Sass errors
  0.40     Mon Mar 16 11:04:47 2015
  * Fix reading sass files from SASS_PATH, when using CSS::Sass
* Sat Mar 14 2015 coolo@suse.com
- initial package 0.39
  * created by cpanspec 1.78.08
